Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/hdc1080_simpletest.py
    :caption: examples/hdc1080_simpletest.py
    :lines: 5-

Operation mode settings
------------------------

Example showing the Operation mode setting

.. literalinclude:: ../examples/hdc1080_operation_mode.py
    :caption: examples/hdc1080_operation_mode.py
    :lines: 5-

Temperature resolution settings
--------------------------------

Example showing the Temperature resolution setting

.. literalinclude:: ../examples/hdc1080_temperature_resolution.py
    :caption: examples/hdc1080_temperature_resolution.py
    :lines: 5-

Humidity resolution settings
-----------------------------

Example showing the Humidity resolution setting

.. literalinclude:: ../examples/hdc1080_humidity_resolution.py
    :caption: examples/hdc1080_humidity_resolution.py
    :lines: 5-
